register_tsne: Register Seriation Based on 1D t-SNE
Description
Use t-distributed stochastic neighbor embedding (t-SNE) for seriate().
Usage
register_tsne()
Arguments
Value
Nothing.
Details
Registers the method "tsne" for seriate(). This method applies
1D t-SNE to data represented by a distance matrix and extracts the order
from the 1D embedding. To speed up the process, an initial embedding is
created using multi-dimensional scaling (MDS) which is improved by t-SNE.
The control parameter mds controls if MDS is used to create an
initial embedding. See Rtsne::Rtsne() to learn about the other
available control parameters.
Note: Package Rtsne needs to be installed.
References
van der Maaten, L.J.P. & Hinton, G.E., 2008. Visualizing
High-Dimensional Data Using t-SNE. Journal of Machine Learning Research, 9,
pp.2579-2605.
# NOT RUN {# }# NOT RUN {register_tsne()
get_seriation_method("dist", "tsne")
d <- dist(random.robinson(50, pre=TRUE, noise=.1))
o <- seriate(d, method = "tsne")
pimage(d, o)
# }# NOT RUN {# }